pub struct ChainTipSender {
use_non_finalized_tip: bool,
sender: Sender<Option<ChainTipBlock>>,
}Expand description
A sender for changes to the non-finalized and finalized chain tips.
Fields
use_non_finalized_tip: boolHave we got any chain tips from the non-finalized state?
Once this flag is set, we ignore the finalized state.
None tips don’t set this flag.
sender: Sender<Option<ChainTipBlock>>The sender channel for chain tip data.
Implementations
Sourceimpl ChainTipSender
impl ChainTipSender
Sourcepub fn new(
initial_tip: impl Into<Option<ChainTipBlock>>,
network: &Network,
) -> (Self, LatestChainTip, ChainTipChange)
pub fn new( initial_tip: impl Into<Option<ChainTipBlock>>, network: &Network, ) -> (Self, LatestChainTip, ChainTipChange)
Create new linked instances of ChainTipSender, LatestChainTip, and ChainTipChange,
using an initial_tip and a Network.
Sourcepub fn finalized_sender(&self) -> Self
pub fn finalized_sender(&self) -> Self
Returns a clone of itself for sending finalized tip changes,
used by TrustedChainSync in zebra-rpc.
Sourcepub fn set_finalized_tip(
&mut self,
new_tip: impl Into<Option<ChainTipBlock>> + Clone,
)
pub fn set_finalized_tip( &mut self, new_tip: impl Into<Option<ChainTipBlock>> + Clone, )
Update the latest finalized tip.
May trigger an update to the best tip.
Sourcepub fn set_best_non_finalized_tip(
&mut self,
new_tip: impl Into<Option<ChainTipBlock>> + Clone,
)
pub fn set_best_non_finalized_tip( &mut self, new_tip: impl Into<Option<ChainTipBlock>> + Clone, )
Update the latest non-finalized tip.
May trigger an update to the best tip.
Sourcefn update(&mut self, new_tip: Option<ChainTipBlock>)
fn update(&mut self, new_tip: Option<ChainTipBlock>)
Possibly send an update to listeners.
An update is only sent if the current best tip is different from the last best tip that was sent.
Sourcefn record_new_tip(new_tip: &Option<ChainTipBlock>)
fn record_new_tip(new_tip: &Option<ChainTipBlock>)
Record new_tip in the current span.
Callers should create a new span with empty new_height and new_hash fields.
Sourcefn record_fields(&self, new_tip: &Option<ChainTipBlock>)
fn record_fields(&self, new_tip: &Option<ChainTipBlock>)
Record new_tip and the fields from self in the current span.
The fields recorded are:
new_heightnew_hashold_heightold_hashold_use_non_finalized_tip
Callers should create a new span with the empty fields described above.
Sourcefn record_tip(span: &Span, prefix: &str, tip: &Option<ChainTipBlock>)
fn record_tip(span: &Span, prefix: &str, tip: &Option<ChainTipBlock>)
Record tip into span using the prefix to name the fields.
Callers should create a new span with empty {prefix}_height and {prefix}_hash fields.